DebugInfo

Struct DebugInfo 

pub struct DebugInfo<'a> { /* private fields */ }
Available on crate feature debug only.
A catch-all box of tricks for debugging a parser.

Implementations

Source

impl<'a> DebugInfo<'a>

pub fn to_ebnf(&self) -> String

Generate a string containing an eBNF grammar for this parser.

The exact format of the grammar definition is not specified, and is only intended to be read by a human being.

pub fn to_railroad_svg(&self) -> impl Display + Clone

Generate a human-readable railroad diagram that describes the grammar.

The resulting diagram is in SVG format and may be printed to the console, written to a file, etc.

The exact format of the diagram is not specified and its quality may depend heavily on annotations, such as Parser::labelled. Aspects of the grammar may also not be captured. For example, context-sensitive parsers are largely ignored today.

Examples

Here is a generated railroad diagram for the example JSON parser. See examples/json.rs in the repository.

A railroad diagram of the grammar for JSON