pub struct RollbackState<T>(pub T);Expand description
A state type that clones and rolls back its contents during a rewind.
This might be useful if you want to use the parser state to, say, count the parsed occurrences of a particular construct.
Ideally, you should try to have the Clone implementation be fairly cheap.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Clone> Clone for RollbackState<T>
impl<T: Clone> Clone for RollbackState<T>
Sourcefn clone(&self) -> RollbackState<T>
fn clone(&self) -> RollbackState<T>
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug> Debug for RollbackState<T>
impl<T: Debug> Debug for RollbackState<T>
Sourceimpl<T: Default> Default for RollbackState<T>
impl<T: Default> Default for RollbackState<T>
Sourcefn default() -> RollbackState<T>
fn default() -> RollbackState<T>
Returns the “default value” for a type. Read more
Sourceimpl<T> Deref for RollbackState<T>
impl<T> Deref for RollbackState<T>
Sourceimpl<T> DerefMut for RollbackState<T>
impl<T> DerefMut for RollbackState<T>
Sourceimpl<T> From<T> for RollbackState<T>
impl<T> From<T> for RollbackState<T>
Sourceimpl<'src, T: Clone, I: Input<'src>> Inspector<'src, I> for RollbackState<T>
impl<'src, T: Clone, I: Input<'src>> Inspector<'src, I> for RollbackState<T>
Sourcetype Checkpoint = T
type Checkpoint = T
A type the Inspector can use to revert to a previous state. Read more
Sourcefn on_token(&mut self, _: &<I as Input<'src>>::Token)
fn on_token(&mut self, _: &<I as Input<'src>>::Token)
This function is called when a new token is read from the input stream.
Sourcefn on_save<'parse>(&self, _: &Cursor<'src, 'parse, I>) -> Self::Checkpoint
fn on_save<'parse>(&self, _: &Cursor<'src, 'parse, I>) -> Self::Checkpoint
This function is called when a combinator saves the current state of the parse.
Sourcefn on_rewind<'parse>(
&mut self,
cp: &Checkpoint<'src, 'parse, I, Self::Checkpoint>,
)
fn on_rewind<'parse>( &mut self, cp: &Checkpoint<'src, 'parse, I, Self::Checkpoint>, )
This function is called when a combinator rewinds to an earlier state of the parser. Read more
impl<T: Copy> Copy for RollbackState<T>