pub struct SimpleState<T>(pub T);Expand description
A state type that should be accessible directly from parser.state() and has no special behavior.
This wrapper implements the Inspector trait for you so you don’t have to.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Clone> Clone for SimpleState<T>
impl<T: Clone> Clone for SimpleState<T>
Sourcefn clone(&self) -> SimpleState<T>
fn clone(&self) -> SimpleState<T>
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug> Debug for SimpleState<T>
impl<T: Debug> Debug for SimpleState<T>
Sourceimpl<T: Default> Default for SimpleState<T>
impl<T: Default> Default for SimpleState<T>
Sourcefn default() -> SimpleState<T>
fn default() -> SimpleState<T>
Returns the “default value” for a type. Read more
Sourceimpl<T> Deref for SimpleState<T>
impl<T> Deref for SimpleState<T>
Sourceimpl<T> DerefMut for SimpleState<T>
impl<T> DerefMut for SimpleState<T>
Sourceimpl<T> From<T> for SimpleState<T>
impl<T> From<T> for SimpleState<T>
Sourceimpl<'src, T, I: Input<'src>> Inspector<'src, I> for SimpleState<T>
impl<'src, T, I: Input<'src>> Inspector<'src, I> for SimpleState<T>
Sourcetype Checkpoint = ()
type Checkpoint = ()
A type the Inspector can use to revert to a previous state. Read more
Sourcefn on_token(&mut self, _: &<I as Input<'src>>::Token)
fn on_token(&mut self, _: &<I as Input<'src>>::Token)
This function is called when a new token is read from the input stream.
Sourcefn on_save<'parse>(&self, _: &Cursor<'src, 'parse, I>) -> Self::Checkpoint
fn on_save<'parse>(&self, _: &Cursor<'src, 'parse, I>) -> Self::Checkpoint
This function is called when a combinator saves the current state of the parse.
Sourcefn on_rewind<'parse>(
&mut self,
_: &Checkpoint<'src, 'parse, I, Self::Checkpoint>,
)
fn on_rewind<'parse>( &mut self, _: &Checkpoint<'src, 'parse, I, Self::Checkpoint>, )
This function is called when a combinator rewinds to an earlier state of the parser. Read more
impl<T: Copy> Copy for SimpleState<T>