Re-exports
pub use label::LabelError;
Structs
- Cheap
- A very cheap error type that tracks only the error span (
SimpleSpanby default). This type is most useful when you want fast parsing but do not particularly care about the quality of error messages. - Empty
Err - A ZST error type that tracks only whether a parse error occurred at all. This type is for when you want maximum parse speed, at the cost of all error reporting.
- Rich
- A rich default error type that tracks error spans, expected inputs, and the actual input found at an error site.
- Simple
- A simple error type that tracks the error span (
SimpleSpanby default) and found token. This type is most useful when you want fast parsing but do not particularly care about the quality of error messages.
Enums
- Rich
Pattern - An expected pattern for a
Richerror. - Rich
Reason - The reason for a
Richerror.
Traits
- Error
- A trait that describes parser error types.