pub enum RichReason<'a, T> {
ExpectedFound {
expected: Vec<RichPattern<'a, T>>,
found: Option<MaybeRef<'a, T>>,
},
Custom(String),
}Expand description
The reason for a Rich error.
Variants
ExpectedFound
An unexpected input was found
Fields

expected: Vec<RichPattern<'a, T>>The tokens expected
Custom(String)
An error with a custom message
Implementations
Sourceimpl<'a, T> RichReason<'a, T>
impl<'a, T> RichReason<'a, T>
Sourcepub fn found(&self) -> Option<&T>
pub fn found(&self) -> Option<&T>
Return the token that was found by this error reason. None implies that the end of input was expected.
Sourcepub fn into_owned<'b>(self) -> RichReason<'b, T>where
T: Clone,
pub fn into_owned<'b>(self) -> RichReason<'b, T>where
T: Clone,
Convert this reason into an owned version of itself by cloning any borrowed internal tokens, if necessary.
Sourcepub fn map_token<U, F: FnMut(T) -> U>(self, f: F) -> RichReason<'a, U>where
T: Clone,
pub fn map_token<U, F: FnMut(T) -> U>(self, f: F) -> RichReason<'a, U>where
T: Clone,
Transform this RichReason’s tokens using the given function.
This is useful when you wish to combine errors from multiple compilation passes (lexing and parsing, say) where
the token type for each pass is different (char vs MyToken, say).