Cheap

Struct Cheap 

pub struct Cheap<S = SimpleSpan<usize>> { /* private fields */ }
A very cheap error type that tracks only the error span (SimpleSpan by default). This type is most useful when you want fast parsing but do not particularly care about the quality of error messages.

Examples

use chumsky::prelude::*;

let parser = just::<_, _, extra::Err<Cheap>>("+");
let error = parser.parse("-").into_errors()[0];

assert_eq!(error.span(), &SimpleSpan::new((), 0..1));

Implementations

Source

impl<S> Cheap<S>

pub fn new(span: S) -> Self

Create a new Cheap error.

pub fn span(&self) -> &S

Get the span than that error related to.

If the span type is unspecified, it is SimpleSpan.