pub struct Cheap<S = SimpleSpan<usize>> { /* private fields */ }Expand description
A very cheap error type that tracks only the error span (SimpleSpan by default).
This type is most useful when you want fast parsing but do not particularly care about the quality of error messages.
Examples
use chumsky::prelude::*;
let parser = just::<_, _, extra::Err<Cheap>>("+");
let error = parser.parse("-").into_errors()[0];
assert_eq!(error.span(), &SimpleSpan::new((), 0..1));Implementations