Parsers and utilities for working with unicode inputs.
Structs
- Grapheme
- A type containing one extended Unicode grapheme cluster.
- Graphemes
- A type containing any number of extended Unicode grapheme clusters.
- Graphemes
Iter - Grapheme iterator type.
Functions
- ident
- A parser that accepts an identifier.
- is_
whitespace - Like
char::is_whitespace, but rejects the characters U+202A, U+202B, U+202C, U+202D, U+202E, U+2066, U+2067, U+2068, U+2069 to mitigate against CVE-2021-42574 - keyword
- Like
ident, but only accepts a specific identifier while rejecting trailing identifier characters.